@@ -1,6 +1,6 @@
 package Calendar::Saka;
 
-$Calendar::Saka::VERSION   = '1.32';
+$Calendar::Saka::VERSION   = '1.33';
 $Calendar::Saka::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Calendar::Saka - Interface to Indian Calendar.
 
 =head1 VERSION
 
-Version 1.32
+Version 1.33
 
 =cut
 
@@ -230,29 +230,6 @@ sub as_string {
     return $self->as_text($self->month, $self->year);
 }
 
-#
-#
-# PRIVATE METHODS
-
-sub validate_params {
-    my ($self, $month, $year) = @_;
-
-    if (defined $month && defined $year) {
-        $self->date->validate_month($month);
-        $self->date->validate_year($year);
-
-        if ($month !~ /^\d+$/) {
-            $month = $self->date->get_month_number($month);
-        }
-    }
-    else {
-        $month = $self->month;
-        $year  = $self->year;
-    }
-
-    return ($month, $year);
-}
-
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
